/*
Copyright (c) 2023-present NAVER Corp.
name: @egjs/view360
license: MIT
author: NAVER Corp.
repository: https://github.com/naver/egjs-view360
version: 4.0.0-beta.7
*/
'use strict';

var Vue = require('vue');
var VanillaView360 = require('@egjs/view360');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return n;
}

var Vue__default = /*#__PURE__*/_interopDefault(Vue);
var VanillaView360__namespace = /*#__PURE__*/_interopNamespace(VanillaView360);

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};

var view360OptionNames = Object.getOwnPropertyNames(VanillaView360__namespace["default"].prototype).filter(function (name) {
  var descriptor = Object.getOwnPropertyDescriptor(VanillaView360__namespace["default"].prototype, name);
  if (name.startsWith("_")) return false;
  if (descriptor === null || descriptor === void 0 ? void 0 : descriptor.value) return false;
  return true;
});
var view360Options = view360OptionNames.reduce(function (props, name) {
  var _a;
  return __assign(__assign({}, props), (_a = {}, _a[name] = null, _a));
}, {});
var view360SetterNames = view360OptionNames.filter(function (name) {
  var descriptor = Object.getOwnPropertyDescriptor(VanillaView360__namespace["default"].prototype, name);
  return !!descriptor.set;
});
var View360 = Vue__default["default"].extend({
  props: __assign(__assign({}, view360Options), {
    tag: {
      type: String,
      required: false,
      default: "div"
    },
    canvasClass: {
      type: String,
      required: false,
      default: ""
    }
  }),
  created: function () {
    VanillaView360.withMethods(this, "_view360");
  },
  mounted: function () {
    var _this = this;
    var props = VanillaView360.getValidProps(this.$props);
    this._view360 = new VanillaView360__namespace["default"](this.$refs.container, props);
    var events = Object.keys(VanillaView360.EVENTS).map(function (key) {
      return VanillaView360.EVENTS[key];
    });
    events.forEach(function (eventName) {
      _this._view360.on(eventName, function (e) {
        e.target = _this;
        // Make events from camelCase to kebab-case
        _this.$emit(eventName.replace(/([A-Z])/g, "-$1").toLowerCase(), e);
      });
    });
  },
  beforeDestroy: function () {
    var _a;
    (_a = this._view360) === null || _a === void 0 ? void 0 : _a.destroy();
  },
  render: function (h) {
    var _a;
    var canvasClass = (_a = this.canvasClass) !== null && _a !== void 0 ? _a : "";
    var canvasClassName = "".concat(VanillaView360.DEFAULT_CLASS.CANVAS, " ").concat(canvasClass).trim();
    return h(this.tag, {
      ref: "container",
      staticClass: VanillaView360.DEFAULT_CLASS.CONTAINER
    }, [h("canvas", {
      staticClass: canvasClassName
    }), this.$slots.default]);
  },
  watch: __assign({}, view360SetterNames.reduce(function (setters, name) {
    setters["$props.".concat(name)] = {
      handler: function (newVal) {
        if (!this._view360) return;
        this._view360[name] = newVal;
      },
      deep: true
    };
    return setters;
  }, {}))
});

for (var name_1 in VanillaView360__namespace) {
  View360[name_1] = VanillaView360__namespace[name_1];
}
var version = "4.0.0-beta.7";
var install = function (Vue) {
  Vue.component("View360", View360);
};
var plugin = {
  View360: View360,
  install: install,
  version: version
};

module.exports = plugin;
//# sourceMappingURL=view360.cjs.js.map
